RemoteAudioState enum
Remote audio stream state.
Values
- remoteAudioStateStopped → const RemoteAudioState
-
0: The default initial state of the remote audio. This state is reported in cases of remoteAudioReasonLocalMuted, remoteAudioReasonRemoteMuted, or remoteAudioReasonRemoteOffline.
- remoteAudioStateStarting → const RemoteAudioState
-
1: The local user has received the first packet of the remote audio.
- remoteAudioStateDecoding → const RemoteAudioState
-
2: The remote audio stream is decoding and playing normally. This state is reported in cases of remoteAudioReasonNetworkRecovery, remoteAudioReasonLocalUnmuted, or remoteAudioReasonRemoteUnmuted.
- remoteAudioStateFrozen → const RemoteAudioState
-
3: The remote audio stream is frozen. This state is reported in the case of remoteAudioReasonNetworkCongestion.
- remoteAudioStateFailed → const RemoteAudioState
-
4: The remote audio stream failed to play. This state is reported in the case of remoteAudioReasonInternal.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RemoteAudioState> - A constant List of the values in this enum, in order of their declaration.